==> img0ch-2.1.15.tar.bz2: img0ch/_template/type/search_image.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title>img0ch - 摜</title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>?v=<?cs var:html_escape(SecuredVersion) ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript">
//<![CDATA[
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
jQuery(function(){
    jQuery("//input[@name='word']").get(0).focus();
});
function redir(element) {
    app.redirectRenderer( element,
        { "theme": "<?cs var:html_escape(BBS_TYPE_THEME) ?>" } );
    return true;
}
//]]>
</script>
<style type="text/css">
img { border: 0px; }
div#searchForm {
  text-align: center;
  margin-left: auto;
  margin-right: auto;
}
<?cs var:TagCloudCSS ?>
</style>
<?cs var:META ?>
</head>
<body>

<?cs if:Banner ?>
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<hr class="sep" />
<?cs /if ?>

<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject">u<?cs var:html_escape(BBS_TITLE) ?>v̉摜</span>
 </h2>
 <div class="form">
  <form action="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi" method="post">
  <div class="caption">
   <p>
    <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
    <a href="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi/<?cs var:html_escape(BBS) ?>/">tH[</a>
   </p>
  </div>
  <div id="searchForm" class="section">
   <div class="field"><input type="text" name="word" size="70" /></div>
   <div><input type="submit" name="submit" value="̃^OŌ" /></div>
   <div class="hidden_field"><input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" /></div>
  </div>
  </form>
 </div>
 <div class="body">
  <div class="caption">
   <p>u<?cs var:html_escape(BBS_TITLE) ?>ṽ^Oꗗ</p>
  </div>
  <div class="section">
   <p><?cs var:TagCloudHTML ?></p>
  </div>
 </div>
</div>

<?cs if:Total ?>
<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject">
   u<?cs var:html_escape(Word) ?>v̌ʁF<?cs var:html_escape(Total) ?>
  </span>
 </h2>
 <div class="body">
  <div class="caption">
   <p>
<?cs if:Prev ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(WordURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>">&lt;&lt;O</a><?cs /if ?>
<?cs each:item = Pages ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(WordURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>">[<?cs var:html_escape(item.num) ?>]</a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(WordURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>">&gt;&gt;</a><?cs /if ?>
   </p>
  </div>
  <?cs each:item = Result ?>
  <div class="section">
   <p>
    <?cs if:item.thumbpath ?><a href="<?cs var:html_escape(item.url) ?>"><img class="image" src="<?cs var:html_escape(item.thumbpath) ?>" width="<?cs var:html_escape(item.width2) ?>" height="<?cs var:html_escape(item.height2) ?>" alt="<?cs var:html_escape(item.resno) ?>.<?cs var:html_escape(item.extension) ?> (<?cs var:html_escape(item.width) ?>x<?cs var:html_escape(item.height) ?>)"></a><?cs else ?><a href="<?cs var:html_escape(item.url) ?>"><?cs var:html_escape(item.resno) ?>.<?cs var:html_escape(item.extension) ?></a><?cs /if ?><br />XbhF&nbsp;<a href="<?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/<?cs var:item.resno ?>" onclick="redir(this)"><?cs var:item.subject ?></a>&nbsp;(<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/<?cs var:item.resno ?>">t@CǗ</a>)<br />t@C̃nbVF&nbsp;<?cs var:item.hash ?>
   </p>
  </div>
  <?cs /each ?>
 </div>
</div>
<?cs /if ?>

<div class="footer" id="VERSION"><a href="http://img0ch.sourceforge.jp">img0ch-sf.cgi - img0ch BBS</a></div>

</body>
</html>

==> img0ch-2.1.21.tar.bz2: img0ch/_template/type/search_image.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title>img0ch - 摜</title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
<script type="text/javascript">
//<![CDATA[
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
jQuery(function(){
    jQuery("//input[@name='word']").get(0).focus();
});
function redir(element) {
    app.redirectRenderer( element,
        { "theme": "<?cs var:html_escape(BBS_TYPE_THEME) ?>" } );
    return true;
}
//]]>
</script>
<style type="text/css">
img { border: 0px; }
div#searchForm {
  text-align: center;
  margin-left: auto;
  margin-right: auto;
}
<?cs var:TagCloudCSS ?>
</style>
<?cs var:META ?>
</head>
<body>

<?cs if:Banner ?>
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<hr class="sep" />
<?cs /if ?>

<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject">u<?cs var:html_escape(BBS_TITLE) ?>v̉摜</span>
 </h2>
 <div class="form">
  <form action="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi" method="post">
  <div class="caption">
   <p>
    <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
    <a href="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi/<?cs var:html_escape(BBS) ?>/">tH[</a>
    <a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/">fS</a>
   </p>
  </div>
  <div id="searchForm" class="section">
   <div class="field"><input type="text" name="word" size="70" /></div>
   <div><input type="submit" name="submit" value="̃^OŌ" /></div>
   <div class="hidden_field"><input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" /></div>
  </div>
  </form>
 </div>
 <div class="body">
  <div class="caption">
   <p>u<?cs var:html_escape(BBS_TITLE) ?>ṽ^Oꗗ</p>
  </div>
  <div class="section">
   <p><?cs var:TagCloudHTML ?></p>
  </div>
 </div>
</div>

<?cs if:Total ?>
<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject">
   u<?cs var:html_escape(Word) ?>v̌ʁF<?cs var:html_escape(Total) ?>
  </span>
 </h2>
 <div class="body">
  <div class="caption">
   <p>
<?cs if:Prev ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(WordURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>">&lt;&lt;O</a><?cs /if ?>
<?cs each:item = Pages ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(WordURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>">[<?cs var:html_escape(item.num) ?>]</a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(WordURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>">&gt;&gt;</a><?cs /if ?>
   </p>
  </div>
  <?cs each:item = Result ?>
  <div class="section">
   <p>
    <?cs if:item.thumbpath ?><a href="<?cs var:html_escape(item.url) ?>"><img class="image" src="<?cs var:html_escape(item.thumbpath) ?>" width="<?cs var:html_escape(item.width2) ?>" height="<?cs var:html_escape(item.height2) ?>" alt="<?cs var:html_escape(item.resno) ?>.<?cs var:html_escape(item.extension) ?> (<?cs var:html_escape(item.width) ?>x<?cs var:html_escape(item.height) ?>)"></a><?cs else ?><a href="<?cs var:html_escape(item.url) ?>"><?cs var:html_escape(item.resno) ?>.<?cs var:html_escape(item.extension) ?></a><?cs /if ?><br />XbhF&nbsp;<a href="<?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/<?cs var:item.resno ?>" onclick="redir(this)"><?cs var:item.subject ?></a>&nbsp;(<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/<?cs var:item.resno ?>">t@CǗ</a>)<br />t@C̃nbVF&nbsp;<?cs var:item.hash ?>
   </p>
  </div>
  <?cs /each ?>
 </div>
</div>
<?cs /if ?>

<div class="footer" id="VERSION"><a href="http://img0ch.sourceforge.jp">img0ch-sf.cgi - img0ch BBS</a></div>

</body>
</html>
